==> babel-code-frame-6.20.5.tgz: babel-code-frame/README.md <==
# Installation
> `npm install --save @types/babel-code-frame`

# Summary
This package contains type definitions for babel-code-frame (https://github.com/babel/babel/tree/master/packages).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-code-frame.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-code-frame/index.d.ts)
````ts
// Type definitions for babel-code-frame 6.20
// Project: https://github.com/babel/babel/tree/master/packages, https://babeljs.io
// Definitions by: Mohsen Azimi <https://github.com/mohsen1>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

interface BabelCodeFrameOptions {
    /** Syntax highlight the code as JavaScript for terminals. default: false */
    highlightCode?: boolean | undefined;
    /**  The number of lines to show above the error. default: 2 */
    linesBelow?: number | undefined;
    /**  The number of lines to show below the error. default: 3 */
    linesAbove?: number | undefined;
    /**
     * Forcibly syntax highlight the code as JavaScript (for non-terminals);
     * overrides highlightCode.
     * default: false
     */
    forceColor?: boolean | undefined;
}

/**
 * Generate errors that contain a code frame that point to source locations.
 *
 * @param rawLines Raw lines to frame
 * @param lineNumber Line number (1 indexed)
 * @param colNumber Column number
 * @param options Additional options
 *
 * @returns Framed code
 */
declare function codeFrame(
    rawLines: string,
    lineNumber: number,
    colNumber: number,
    options?: BabelCodeFrameOptions
): string;

export = codeFrame;

````

### Additional Details
 * Last updated: Tue, 06 Jul 2021 18:05:38 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Mohsen Azimi](https://github.com/mohsen1).

==> babel-code-frame-6.20.6.tgz: babel-code-frame/README.md <==
# Installation
> `npm install --save @types/babel-code-frame`

# Summary
This package contains type definitions for babel-code-frame (https://github.com/babel/babel/tree/master/packages).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-code-frame.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/babel-code-frame/index.d.ts)
````ts
// Type definitions for babel-code-frame 6.20
// Project: https://github.com/babel/babel/tree/master/packages, https://babeljs.io
// Definitions by: Mohsen Azimi <https://github.com/mohsen1>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

interface BabelCodeFrameOptions {
    /** Syntax highlight the code as JavaScript for terminals. default: false */
    highlightCode?: boolean | undefined;
    /**  The number of lines to show above the error. default: 2 */
    linesBelow?: number | undefined;
    /**  The number of lines to show below the error. default: 3 */
    linesAbove?: number | undefined;
    /**
     * Forcibly syntax highlight the code as JavaScript (for non-terminals);
     * overrides highlightCode.
     * default: false
     */
    forceColor?: boolean | undefined;
}

/**
 * Generate errors that contain a code frame that point to source locations.
 *
 * @param rawLines Raw lines to frame
 * @param lineNumber Line number (1 indexed)
 * @param colNumber Column number
 * @param options Additional options
 *
 * @returns Framed code
 */
declare function codeFrame(
    rawLines: string,
    lineNumber: number,
    colNumber: number,
    options?: BabelCodeFrameOptions,
): string;

export = codeFrame;

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 19:06:48 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Mohsen Azimi](https://github.com/mohsen1).
